@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 requires qw/ log_stats /;
 
-our $VERSION = 'v0.5.0';
+our $VERSION = 'v0.5.1';
 
 
 sub statsd_client {
@@ -80,7 +80,7 @@ Catalyst::Plugin::Statsd - log Catalyst stats to statsd
 
 =head1 VERSION
 
-version v0.5.0
+version v0.5.1
 
 =head1 SYNOPSIS
 
@@ -171,6 +171,27 @@ metric C<catalyst.stats.foo.bar.time>.
 
 The metric name is generated by L</statsd_metric_name_filter>.
 
+=head1 KNOWN ISSUES
+
+=head2 Custom Profiling Points
+
+If you have custom profiling points, then these will be treated as
+top-level names in the C<catalyst.stats.*> namespaces, e.g.
+
+  my $stats = $c->stats;
+  $stats->profile( begin => 'here' );
+
+  ...
+
+  $stats->profile( end => 'here' );
+
+will be logged to statsd in the C<statlyst.stats.here.time> namespace.
+
+If you do not want this, then you can work around this by prefixing
+the block name with a controller name, e.g.
+
+  $stats->profile( begin => 'controller.here' );
+
 =head1 SEE ALSO
 
 =over
@@ -214,7 +235,7 @@ Slaven Rezić <slaven@rezic.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Robert Rothenberg.
+This software is Copyright (c) 2018-2019 by Robert Rothenberg.
 
 This is free software, licensed under:
 
